@@ -1,7 +1,7 @@
 /*
  * Copyright (C) Igor Sysoev
  * Copyright (C) 2007 Manlio Perillo (manlio.perillo@gmail.com)
- * Copyright (c) 2010-2017 Phusion Holding B.V.
+ * Copyright (c) 2010-2025 Asynchronous B.V.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -50,7 +50,6 @@
 
 #include "ngx_http_passenger_module.h"
 #include "Configuration.h"
-#include "ContentHandler.h"
 #include "cxx_supportlib/Constants.h"
 #include "cxx_supportlib/vendor-modified/modp_b64.cpp" /* File is C compatible. */
 #include "cxx_supportlib/vendor-modified/modp_b64_strict_aliasing.cpp" /* File is C compatible. */
@@ -359,6 +358,7 @@ start_watchdog(ngx_cycle_t *cycle) {
     psg_json_value_set_str_ne    (w_config, "server_software", NGINX_VER, strlen(NGINX_VER));
     psg_json_value_set_bool      (w_config, "multi_app", 1);
     psg_json_value_set_bool      (w_config, "default_load_shell_envvars", 1);
+    psg_json_value_set_bool      (w_config, "default_preload_bundler", 0);
     psg_json_value_set_value     (w_config, "config_manifest", -1, passenger_main_conf.manifest);
     psg_json_value_set_ngx_uint  (w_config, "log_level", autogenerated_main_conf->log_level);
     psg_json_value_set_ngx_str_ne(w_config, "file_descriptor_log_target", &autogenerated_main_conf->file_descriptor_log_file);
@@ -375,6 +375,7 @@ start_watchdog(ngx_cycle_t *cycle) {
     psg_json_value_set_ngx_flag  (w_config, "user_switching", autogenerated_main_conf->user_switching);
     psg_json_value_set_ngx_flag  (w_config, "show_version_in_header", autogenerated_main_conf->show_version_in_header);
     psg_json_value_set_ngx_flag  (w_config, "turbocaching", autogenerated_main_conf->turbocaching);
+    psg_json_value_set_ngx_flag  (w_config, "old_routing", autogenerated_main_conf->old_routing);
     psg_json_value_set_ngx_str_ne(w_config, "default_user", &autogenerated_main_conf->default_user);
     psg_json_value_set_ngx_str_ne(w_config, "default_group", &autogenerated_main_conf->default_group);
     psg_json_value_set_ngx_str_ne(w_config, "default_ruby", &passenger_main_conf.default_ruby);
@@ -383,10 +384,6 @@ start_watchdog(ngx_cycle_t *cycle) {
     psg_json_value_set_ngx_uint  (w_config, "max_instances_per_app", autogenerated_main_conf->max_instances_per_app);
     psg_json_value_set_ngx_uint  (w_config, "response_buffer_high_watermark", autogenerated_main_conf->response_buffer_high_watermark);
     psg_json_value_set_ngx_uint  (w_config, "stat_throttle_rate", autogenerated_main_conf->stat_throttle_rate);
-    psg_json_value_set_ngx_str_ne(w_config, "admin_panel_url", &autogenerated_main_conf->admin_panel_url);
-    psg_json_value_set_ngx_str_ne(w_config, "admin_panel_auth_type", &autogenerated_main_conf->admin_panel_auth_type);
-    psg_json_value_set_ngx_str_ne(w_config, "admin_panel_username", &autogenerated_main_conf->admin_panel_username);
-    psg_json_value_set_ngx_str_ne(w_config, "admin_panel_password", &autogenerated_main_conf->admin_panel_password);
 
     if (autogenerated_main_conf->prestart_uris != NGX_CONF_UNSET_PTR) {
         psg_json_value_set_strset(w_config, "prestart_urls", (ngx_str_t *) autogenerated_main_conf->prestart_uris->elts,
