@@ -1,9 +1,9 @@
 /*
  *  Phusion Passenger - https://www.phusionpassenger.com/
- *  Copyright (c) 2010-2014 Phusion Holding B.V.
+ *  Copyright (c) 2010-2025 Asynchronous B.V.
  *
  *  "Passenger", "Phusion Passenger" and "Union Station" are registered
- *  trademarks of Phusion Holding B.V.
+ *  trademarks of Asynchronous B.V.
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a copy
  *  of this software and associated documentation files (the "Software"), to deal
@@ -577,6 +577,22 @@ fs_watcher_free(void *obj) {
 	free(watcher);
 }
 
+static size_t
+fs_watcher_size(const void *obj) {
+	return sizeof(FSWatcher);
+}
+
+static const rb_data_type_t fs_watcher_type = {
+	.wrap_struct_name = "fs_watcher",
+	.function = {
+		.dmark = NULL,
+		.dfree = fs_watcher_free,
+		.dsize = fs_watcher_size,
+	},
+	.data = NULL,
+	.flags = 0, // we unlock gvl so probably can't use RUBY_TYPED_FREE_IMMEDIATELY
+};
+
 static VALUE
 fs_watcher_init(VALUE arg) {
 	FSWatcher *watcher = (FSWatcher *) arg;
@@ -672,7 +688,7 @@ end:
 		watcher->fds = NULL;
 		watcher->fds_len = 0;
 	}
-	return Data_Wrap_Struct(watcher->klass, NULL, fs_watcher_free, watcher);
+	return TypedData_Wrap_Struct(watcher->klass, &fs_watcher_type, watcher);
 }
 
 static VALUE
@@ -789,7 +805,7 @@ fs_watcher_wait_for_change(VALUE self) {
 	int e, interrupted = 0;
 	FSWatcherReadByteData read_data;
 
-	Data_Get_Struct(self, FSWatcher, watcher);
+	TypedData_Get_Struct(self, FSWatcher, &fs_watcher_type, watcher);
 
 	if (watcher->preparation_error) {
 		return Qfalse;
@@ -881,7 +897,7 @@ fs_watcher_wait_for_change(VALUE self) {
 static VALUE
 fs_watcher_close(VALUE self) {
 	FSWatcher *watcher;
-	Data_Get_Struct(self, FSWatcher, watcher);
+	TypedData_Get_Struct(self, FSWatcher, &fs_watcher_type, watcher);
 	fs_watcher_real_close(watcher);
 	return Qnil;
 }
@@ -993,6 +1009,7 @@ Init_passenger_native_support() {
 			fs_watcher_wait_for_change, 0);
 		rb_define_method(cFileSystemWatcher, "close",
 			fs_watcher_close, 0);
+		rb_undef_alloc_func(cFileSystemWatcher);
 	#endif
 
 	/* The maximum length of a Unix socket path, including terminating null. */
